@@ -86,8 +86,11 @@ class Resizer:
         upscale_interpolation="lanczos",
         downscale_interpolation="area",
         encode_quality=95,
+        encode_format="jpg",
         skip_reencode=False,
         disable_all_reencoding=False,
+        min_image_size=0,
+        max_aspect_ratio=float("inf"),
     ):
         self.image_size = image_size
         if isinstance(resize_mode, str):
@@ -98,9 +101,24 @@ class Resizer:
         self.resize_only_if_bigger = resize_only_if_bigger
         self.upscale_interpolation = inter_str_to_cv2(upscale_interpolation)
         self.downscale_interpolation = inter_str_to_cv2(downscale_interpolation)
-        self.encode_params = [int(cv2.IMWRITE_JPEG_QUALITY), encode_quality]
+        self.encode_format = encode_format
+        cv2_img_quality = None
+        if encode_format == "jpg":
+            cv2_img_quality = int(cv2.IMWRITE_JPEG_QUALITY)
+            self.what_ext = "jpeg"
+        elif encode_format == "png":
+            cv2_img_quality = int(cv2.IMWRITE_PNG_COMPRESSION)
+            self.what_ext = "png"
+        elif encode_format == "webp":
+            cv2_img_quality = int(cv2.IMWRITE_WEBP_QUALITY)
+            self.what_ext = "webp"
+        if cv2_img_quality is None:
+            raise Exception(f"Invalid option for encode_format: {encode_format}")
+        self.encode_params = [cv2_img_quality, encode_quality]
         self.skip_reencode = skip_reencode
         self.disable_all_reencoding = disable_all_reencoding
+        self.min_image_size = min_image_size
+        self.max_aspect_ratio = max_aspect_ratio
 
     def __call__(self, img_stream):
         """
@@ -113,7 +131,7 @@ class Resizer:
             with SuppressStdoutStderr():
                 cv2.setNumThreads(1)
                 img_stream.seek(0)
-                encode_needed = imghdr.what(img_stream) != "jpeg" if self.skip_reencode else True
+                encode_needed = imghdr.what(img_stream) != self.what_ext if self.skip_reencode else True
                 img_stream.seek(0)
                 img_buf = np.frombuffer(img_stream.read(), np.uint8)
                 img = cv2.imdecode(img_buf, cv2.IMREAD_UNCHANGED)
@@ -126,6 +144,12 @@ class Resizer:
                     img = np.rint(img.clip(min=0, max=255)).astype(np.uint8)
                     encode_needed = True
                 original_height, original_width = img.shape[:2]
+                # check if image is too small
+                if min(original_height, original_width) < self.min_image_size:
+                    return None, None, None, None, None, "image too small"
+                # check if wrong aspect ratio
+                if max(original_height, original_width) / min(original_height, original_width) > self.max_aspect_ratio:
+                    return None, None, None, None, None, "aspect ratio too large"
 
                 # resizing in following conditions
                 if self.resize_mode in (ResizeMode.keep_ratio, ResizeMode.center_crop):
@@ -151,7 +175,7 @@ class Resizer:
                         encode_needed = True
                 height, width = img.shape[:2]
                 if encode_needed:
-                    img_str = cv2.imencode(".jpg", img, params=self.encode_params)[1].tobytes()
+                    img_str = cv2.imencode(f".{self.encode_format}", img, params=self.encode_params)[1].tobytes()
                 else:
                     img_str = img_buf.tobytes()
                 return img_str, width, height, original_width, original_height, None
